@@ -5,6 +5,9 @@ from PythUnity.Functions import GetPrefab
 from PythUnity.Functions import PrintFonts
 from PythUnity.Variables import *
 from PythUnity.main import init
+from PythUnity.help import help
 from pygame import Rect
 from pygame import image
-from pygame import font
\ No newline at end of file
+from pygame import Surface
+from pygame import font
+
